Welcome to Epigrass’s documentation! — Epigrass 2.0a1 documentation

# Welcome to Epigrass’s documentation!

Epigrass is a framework for the construction and simulation of complex network epidemiology models. At least this is its main vocation. However, Epigrass can be used to simulate any dynamical system on a set of nodes (connected into a network or not!). Epigrass is written in pure Python and is scriptable in Python, for your enjoyment!.

Contents:

- Overview of Epigrass
  - Modeling Approach
  - Geographical Network Models
  - The Simulation
- Building and Installing
  - Required Packages
- Epidemic Models
  - Introduction
  - Disease models
  - Network transportation models
- Using Epigrass
  - Data
  - Specifying a model: the script
  - The Graphical User Interface(GUI)
- Analysis
- Writing Custom Models
  - Getting Started
  - The Environment

# Indices and tables

- Index
- Module Index
- Search Page